# Utility Functions/Classes

## Custom Datatypes

```{eval-rst}
.. automodule:: masci_tools.util.lockable_containers
   :members:
```

```{eval-rst}
.. automodule:: masci_tools.util.case_insensitive_dict
   :members:
```

```{eval-rst}
.. automodule:: masci_tools.util.typing
   :members:
```

## Common XML utility

```{eval-rst}
.. automodule:: masci_tools.util.xml
   :members:
```

```{eval-rst}
.. automodule:: masci_tools.util.xml.common_functions
   :members:
```

```{eval-rst}
.. automodule:: masci_tools.util.xml.converters
   :members:
```

```{eval-rst}
.. automodule:: masci_tools.util.xml.xpathbuilder
   :members:
```

## XML Setter functions

```{eval-rst}
.. automodule:: masci_tools.util.xml.xml_setters_names
   :members:
```

```{eval-rst}
.. automodule:: masci_tools.util.xml.xml_setters_nmmpmat
   :members:
```

```{eval-rst}
.. automodule:: masci_tools.util.xml.xml_setters_xpaths
   :members:
```

```{eval-rst}
.. automodule:: masci_tools.util.xml.xml_setters_basic
   :members:
```

## XML Getter functions

```{eval-rst}
.. automodule:: masci_tools.util.xml.xml_getters
   :members:
```

## Basic IO helper functions

```{eval-rst}
.. automodule:: masci_tools.io.common_functions
   :members:
   :private-members: _TVectorType
```

```{eval-rst}
.. automodule:: masci_tools.io.hdf5_util
   :members:
```

## Logging Utility

```{eval-rst}
.. automodule:: masci_tools.util.logging_util
   :members:
```

## Fleur parser utility

```{eval-rst}
.. automodule:: masci_tools.util.schema_dict_util
   :members:
```

```{eval-rst}
.. automodule:: masci_tools.util.fleur_calculate_expression
   :members:
```

```{eval-rst}
.. automodule:: masci_tools.io.parsers.fleur.outxml_conversions
   :members:
```

```{eval-rst}
.. automodule:: masci_tools.util.econfig
   :members:
```

# Basic Fleur Schema parser functions

```{eval-rst}
.. automodule:: masci_tools.io.parsers.fleur_schema
   :members:
```

```{eval-rst}
.. automodule:: masci_tools.io.parsers.fleur_schema.fleur_schema_parser_functions
   :members:

```

# Defined constants

```{eval-rst}
.. automodule:: masci_tools.util.constants
```
